@@ -880,10 +880,6 @@ Do you want to overwrite?</source>
         <source>Icons size</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>UI style</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Word wrap</source>
         <translation>Zeilenumbruch</translation>
@@ -1871,5 +1867,9 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>FIF at the top (restart needed)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>UI style (restart needed)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
